==> tuia-ecb-center-api-1.1.0.8-happy-20200401.020042-16-sources.jar: cn/com/duiba/tuia/ecb/center/happy/dto/HappyClearPropConfigDTO.java <==
package cn.com.duiba.tuia.ecb.center.happy.dto;

import java.io.Serializable;
import java.util.Date;

public class HappyClearPropConfigDTO implements Serializable {
    private static final long serialVersionUID = -7984711316392649159L;


    private Long id;

    private Long appId;

    private Long activityId;


    /**
     *  {@link cn.com.duiba.tuia.ecb.center.happy.enums.PropTypeEnum}
     *  道具类型
     */
    private Integer propType;

    private String url;

    private Date gmtCreate;

    private Date gmtModified;


    public Long getId() {
        return id;
    }

    public void setId(Long id) {
        this.id = id;
    }

    public Long getAppId() {
        return appId;
    }

    public void setAppId(Long appId) {
        this.appId = appId;
    }

    public Long getActivityId() {
        return activityId;
    }

    public void setActivityId(Long activityId) {
        this.activityId = activityId;
    }

    public Integer getPropType() {
        return propType;
    }

    public void setPropType(Integer propType) {
        this.propType = propType;
    }

    public String getUrl() {
        return url;
    }

    public void setUrl(String url) {
        this.url = url;
    }

    public Date getGmtCreate() {
        return gmtCreate;
    }

    public void setGmtCreate(Date gmtCreate) {
        this.gmtCreate = gmtCreate;
    }

    public Date getGmtModified() {
        return gmtModified;
    }

    public void setGmtModified(Date gmtModified) {
        this.gmtModified = gmtModified;
    }
}

==> tuia-ecb-center-api-1.1.1.54-happy-20210518.022827-4-sources.jar: cn/com/duiba/tuia/ecb/center/happy/dto/HappyClearPropConfigDTO.java <==
package cn.com.duiba.tuia.ecb.center.happy.dto;

import java.io.Serializable;
import java.util.Date;

public class HappyClearPropConfigDTO implements Serializable {
    private static final long serialVersionUID = -7984711316392649159L;


    private Long id;

    private Long appId;

    private Long activityId;

    /**
     *  {@link cn.com.duiba.tuia.ecb.center.happy.enums.PropTypeEnum}
     *  道具类型
     */
    private Integer propType;

    private String url;

    private Integer perNum;

    private Date gmtCreate;

    private Date gmtModified;


    public Long getId() {
        return id;
    }

    public void setId(Long id) {
        this.id = id;
    }

    public Long getAppId() {
        return appId;
    }

    public void setAppId(Long appId) {
        this.appId = appId;
    }

    public Long getActivityId() {
        return activityId;
    }

    public void setActivityId(Long activityId) {
        this.activityId = activityId;
    }

    public Integer getPropType() {
        return propType;
    }

    public void setPropType(Integer propType) {
        this.propType = propType;
    }

    public String getUrl() {
        return url;
    }

    public void setUrl(String url) {
        this.url = url;
    }

    public Date getGmtCreate() {
        return gmtCreate;
    }

    public void setGmtCreate(Date gmtCreate) {
        this.gmtCreate = gmtCreate;
    }

    public Date getGmtModified() {
        return gmtModified;
    }

    public void setGmtModified(Date gmtModified) {
        this.gmtModified = gmtModified;
    }

    public Integer getPerNum() {
        return perNum;
    }

    public void setPerNum(Integer perNum) {
        this.perNum = perNum;
    }
}
